==> archiva-configuration-1.3.1-sources.jar: org/apache/maven/archiva/configuration/UserInterfaceOptions.java <==
/*
 * $Id$
 */

package org.apache.maven.archiva.configuration;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * 
 *         The user interface configuration settings.
 *       
 * 
 * @version $Revision$ $Date$
 */
public class UserInterfaceOptions
    implements java.io.Serializable
{

      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * true if find artifacts should be enabled.
     */
    private boolean showFindArtifacts = true;

    /**
     * true if applet behavior for find artifacts should be enabled.
     */
    private boolean appletFindEnabled = true;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get true if applet behavior for find artifacts should be
     * enabled.
     * 
     * @return boolean
     */
    public boolean isAppletFindEnabled()
    {
        return this.appletFindEnabled;
    } //-- boolean isAppletFindEnabled()

    /**
     * Get true if find artifacts should be enabled.
     * 
     * @return boolean
     */
    public boolean isShowFindArtifacts()
    {
        return this.showFindArtifacts;
    } //-- boolean isShowFindArtifacts()

    /**
     * Set true if applet behavior for find artifacts should be
     * enabled.
     * 
     * @param appletFindEnabled
     */
    public void setAppletFindEnabled( boolean appletFindEnabled )
    {
        this.appletFindEnabled = appletFindEnabled;
    } //-- void setAppletFindEnabled( boolean )

    /**
     * Set true if find artifacts should be enabled.
     * 
     * @param showFindArtifacts
     */
    public void setShowFindArtifacts( boolean showFindArtifacts )
    {
        this.showFindArtifacts = showFindArtifacts;
    } //-- void setShowFindArtifacts( boolean )


}

==> archiva-configuration-1.3.5-sources.jar: org/apache/maven/archiva/configuration/UserInterfaceOptions.java <==
/*
 * $Id$
 */

package org.apache.maven.archiva.configuration;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * 
 *         The user interface configuration settings.
 *       
 * 
 * @version $Revision$ $Date$
 */
public class UserInterfaceOptions
    implements java.io.Serializable
{

      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * true if find artifacts should be enabled.
     */
    private boolean showFindArtifacts = true;

    /**
     * true if applet behavior for find artifacts should be enabled.
     */
    private boolean appletFindEnabled = true;

    /**
     * Field disableEasterEggs.
     */
    private boolean disableEasterEggs = false;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get true if applet behavior for find artifacts should be
     * enabled.
     * 
     * @return boolean
     */
    public boolean isAppletFindEnabled()
    {
        return this.appletFindEnabled;
    } //-- boolean isAppletFindEnabled()

    /**
     * Get the disableEasterEggs field.
     * 
     * @return boolean
     */
    public boolean isDisableEasterEggs()
    {
        return this.disableEasterEggs;
    } //-- boolean isDisableEasterEggs()

    /**
     * Get true if find artifacts should be enabled.
     * 
     * @return boolean
     */
    public boolean isShowFindArtifacts()
    {
        return this.showFindArtifacts;
    } //-- boolean isShowFindArtifacts()

    /**
     * Set true if applet behavior for find artifacts should be
     * enabled.
     * 
     * @param appletFindEnabled
     */
    public void setAppletFindEnabled( boolean appletFindEnabled )
    {
        this.appletFindEnabled = appletFindEnabled;
    } //-- void setAppletFindEnabled( boolean )

    /**
     * Set the disableEasterEggs field.
     * 
     * @param disableEasterEggs
     */
    public void setDisableEasterEggs( boolean disableEasterEggs )
    {
        this.disableEasterEggs = disableEasterEggs;
    } //-- void setDisableEasterEggs( boolean )

    /**
     * Set true if find artifacts should be enabled.
     * 
     * @param showFindArtifacts
     */
    public void setShowFindArtifacts( boolean showFindArtifacts )
    {
        this.showFindArtifacts = showFindArtifacts;
    } //-- void setShowFindArtifacts( boolean )


}
